==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/act/topic/delAction.php <==
<?php
class delAction extends topicAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	if($this->isGuest()){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$tid = $this->getIntRequest('tid', APP_REQUEST_GET);
	$num = $this->getIntRequest('n', APP_REQUEST_GET);
	
	if(!isset($tid) || !isset($num)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$commu_handler =& CM_CommunityHandler::getInstance();
	$topic_handler =& CM_TopicHandler::getInstance();
	$comment_handler =& CM_TopicCommentHandler::getInstance();
	$user_handler =& CM_UserHandler::getInstance();
	
	// ȥԥåμ
	$topic =& $topic_handler->get($tid);
	if(!is_object($topic)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$topic_uid = $topic->getVar('uid');
	
	// ߥ˥ƥμ
	$cid = $topic->getVar('c_commu_id');
	$community =& $commu_handler->get($cid);
	if(!is_object($community)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$commu_auth = $community->getAuthority();
	if($commu_auth < _CM_AUTH_MEMBER){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// Ȥμ
	$comment =& $comment_handler->getByNumber($tid, $num);
	$comment_uid = $comment->getVar('uid');
	if(!is_object($comment) || $comment_uid < 1
	   || ($commu_auth < _CM_AUTH_SUB_ADMIN && $own_uid != $comment_uid && $own_uid != $topic_uid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$author =& $user_handler->get($comment->getVar('uid'));
	$author_info =& $author->getInfo();
	
	$target_topic = array(
		'id' => $tid,
		'number' => $num,
		'title' => $topic->getVar('name'),
		'body' => preg_replace('/\[res\]([1-9]\\d*)\[\/res\]/', '>>\1', $comment->getVar('body', 'p')),
		'author_name' => $author_info['name'],
		'author_url' => $author_info['page_url'],
	);

	$commu = array('id' => $cid, 'name' => $community->getVar('name'));
	$message = ($num==0)? _CM_TOPIC_DEL_CONFIRM : _CM_TOPIC_RES_DEL_CONFIRM;
	
	$context->setAttributes('topic', $target_topic);
	$context->setAttributes('commu', $commu);
	$context->setAttributes('message', $message);
}
}
?>

==> xsns_1.0.5.zip: xsns_1.0.5/xoops_trust_path/modules/xsns/act/topic/delAction.php <==
<?php
class delAction extends topicAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	if($this->isGuest()){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$tid = $this->getIntRequest('tid', APP_REQUEST_GET);
	$num = $this->getIntRequest('n', APP_REQUEST_GET);
	
	if(!isset($tid) || !isset($num)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$commu_handler =& CM_CommunityHandler::getInstance();
	$topic_handler =& CM_TopicHandler::getInstance();
	$comment_handler =& CM_TopicCommentHandler::getInstance();
	$user_handler =& CM_UserHandler::getInstance();
	
	// ȥԥåμ
	$topic =& $topic_handler->get($tid);
	if(!is_object($topic)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$topic_uid = $topic->getVar('uid');
	
	// ߥ˥ƥμ
	$cid = $topic->getVar('c_commu_id');
	$community =& $commu_handler->get($cid);
	if(!is_object($community)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$commu_auth = $community->getAuthority();
	if($commu_auth < _CM_AUTH_MEMBER){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// Ȥμ
	$comment =& $comment_handler->getByNumber($tid, $num);
	$comment_uid = $comment->getVar('uid');
	if(!is_object($comment) || $comment_uid < 1
	   || ($commu_auth < _CM_AUTH_SUB_ADMIN && $own_uid != $comment_uid && $own_uid != $topic_uid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$author =& $user_handler->get($comment->getVar('uid'));
	$author_info = is_object($author) ? $author->getInfo() : array('name'=>'', 'page_url'=>'');
	
	$target_topic = array(
		'id' => $tid,
		'number' => $num,
		'title' => $topic->getVar('name'),
		'body' => preg_replace('/\[res\]([1-9]\\d*)\[\/res\]/', '>>\1', $comment->getVar('body', 'p')),
		'author_name' => $author_info['name'],
		'author_url' => $author_info['page_url'],
	);

	$commu = array('id' => $cid, 'name' => $community->getVar('name'));
	$message = ($num==0)? _CM_TOPIC_DEL_CONFIRM : _CM_TOPIC_RES_DEL_CONFIRM;
	
	$context->setAttributes('topic', $target_topic);
	$context->setAttributes('commu', $commu);
	$context->setAttributes('message', $message);
}
}
?>
